# Lovadira
This is a library python for generate quote Gus Baha

# Gus Baha Quotes Generator

A simple Python library to generate random quotes from Gus Baha.

## Installation

You can install this library using `pip`:

```bash
pip install lovadira

```
Alternatively, to install it manually, run the following commands:

```bash
git clone https://github.com/Anammkh/Lovadira.git
cd Lovadira
python setup.py install

```
## Usage

To use this library, simply import the generate_quote function from the generator module. Here’s an example:

```bash
from lovadira.generator import generate_quote

quote = generate_quote()
print(quote)
```

Each time you run generate_quote(), you will get a different random quote from Gus Baha.

## Contributing
If you'd like to contribute to this project, feel free to fork the repository and submit a pull request with improvements or new features.




